@@ -2,6 +2,10 @@
 #' @description
 #' Calculates the variation inflation factors of all predictors in regression models
 #' @param model is a linear regression model
+#' @examples
+#' model <- lm(real_gdp ~ imp + exp + poil + eurkzt + tonia_rate, data = macroKZ)
+#' vif_reg(model)
+#' @importFrom cli console_width
 #' @references Petrie, Adam. Published 2020-02-21. regclass package
 #' @rdname vif_reg
 #' @export
@@ -35,12 +39,23 @@ vif_reg<-function (model)
   if (all(result[, 2] == 1))
     result <- result[, 1]
   else result[, 3] <- result[, 1]^(1/(2 * result[, 2]))
-  print(result)
+  l<-matrix(result, dimnames=list(terms))
 
+  #print
+  w3 <- console_width()
+  cat(format(as.character("Variance Inflation Factor"), width=w3, justify="centre"), "\n\n")
+  cat(paste("If statistics exceeds 5, please be aware of multicollinearity."), sep='\n')
+
+  cat("\n")
+  print(round(result,3))
+  cat("\n")
 
   l<-matrix(result, dimnames=list(terms))
   for (i in 1:length(l)){
     if (l[i]>5)
-      cat(paste("This value", l[i], "exceeds acceptable threshold"), sep='\n')
+      cat(paste("This value", round(l[i], 3), "exceeds acceptable threshold."), sep='\n')
   }
 }
+
+
+
